@@ -5,17 +5,12 @@ import logging
 
 from eventtracking.processors.exceptions import EventEmissionExit
 
+from event_routing_backends.helpers import get_business_critical_events
 from event_routing_backends.models import RouterConfiguration
-from event_routing_backends.utils.http_client import HttpClient
-from event_routing_backends.utils.xapi_lrs_client import LrsClient
+from event_routing_backends.tasks import dispatch_event, dispatch_event_persistent
 
 logger = logging.getLogger(__name__)
 
-ROUTER_STRATEGY_MAPPING = {
-    'AUTH_HEADERS': HttpClient,
-    'XAPI_LRS': LrsClient,
-}
-
 
 class EventsRouter:
     """
@@ -33,35 +28,25 @@ class EventsRouter:
         self.processors = processors if processors else []
         self.backend_name = backend_name
 
-    def _copy(self, event):
-        """
-        Copy the event to avoid mutation.
-
-        Currently supports only `dict` type events.
-        """
-        if isinstance(event, dict):
-            return event.copy()
-        else:
-            raise ValueError('Expected event as dict but {type} was given.'.format(type=type(event)))
-
     def send(self, event):
         """
         Send the event to configured routers after processing it.
 
         Event is processed through the configured processors. A router config
-        object matching the backend_name is used to get the list of hosts to
-        which the event is required to be delivered to.
-        Then a client as per the router configurations will be used to deliver the
-        event.
+        object matching the backend_name and other match params is used to get
+        the list of hosts to which the event is required to be delivered to.
 
         Arguments:
-            original_event (dict):      original event dictionary
-            transformed_event (dict):   transformed event dictionary
+            event (dict):      original event dictionary
         """
+        try:
+            event_name = event['name']
+        except TypeError as exc:
+            raise ValueError('Expected event as dict but {type} was given.'.format(type=type(event))) from exc
         try:
             logger.debug(
                 'Processing event %s for router with backend %s',
-                event,
+                event['name'],
                 self.backend_name
             )
 
@@ -69,38 +54,49 @@ class EventsRouter:
         except EventEmissionExit:
             logger.error(
                 'Could not process event %s for backend %s\'s router',
-                event,
+                event_name,
                 self.backend_name,
                 exc_info=True
             )
             return
 
         logger.debug('Successfully processed event %s for router with backend %s',
-                     event, self.backend_name)
+                     event_name, self.backend_name)
 
-        router = RouterConfiguration.get_enabled_router(self.backend_name)
+        routers = RouterConfiguration.get_enabled_routers(self.backend_name)
 
-        if not router:
+        if not routers:
             logger.error('Could not find an enabled router configurations for backend %s', self.backend_name)
             return
 
-        hosts = router.get_allowed_hosts(event)
-        if not hosts:
-            logger.info(
-                'Event %s is not allowed to be sent to any host for router with backend "%s"',
-                event, self.backend_name
-            )
-            return
+        for router in routers:
+            hosts = router.get_allowed_hosts(event)
 
-        for host in hosts:
-            updated_event = self.overwrite_event_data(processed_event, host)
+            router_url = router.route_url
+            if not hosts:
+                logger.info(
+                    'Event %s is not allowed to be sent to any host for router %s with backend "%s"',
+                    event_name, router_url, self.backend_name
+                )
 
-            self.dispatch_event(
-                event,
-                updated_event,
-                host['router_type'],
-                host['host_configurations']
-            )
+            for host in hosts:
+                updated_event = self.overwrite_event_data(processed_event, host)
+                host['host_configurations'].update({'url': router_url})
+                business_critical_events = get_business_critical_events()
+                if event_name in business_critical_events:
+                    dispatch_event_persistent.delay(
+                        event,
+                        updated_event,
+                        host['router_type'],
+                        host['host_configurations']
+                    )
+                else:
+                    dispatch_event.delay(
+                        event,
+                        updated_event,
+                        host['router_type'],
+                        host['host_configurations']
+                    )
 
     def process_event(self, event):
         """
@@ -112,7 +108,7 @@ class EventsRouter:
         Returns
             dict
         """
-        event = self._copy(event)
+        event = event.copy()
         for processor in self.processors:
             event = processor(event)
 
@@ -133,47 +129,7 @@ class EventsRouter:
             dict
         """
         if 'override_args' in host and isinstance(event, dict):
-            event = self._copy(event)
+            event = event.copy()
             event.update(host['override_args'])
             logger.debug('Overwriting event with values {}'.format(host['override_args']))
         return event
-
-    def dispatch_event(self, event_name, event, router_type, host_config):
-        """
-        Send event to configured client.
-
-        Arguments:
-            event_name (str)    : name of the original event
-            event (dict)        : event dictionary to be delivered.
-            router_type (str)   : decides the client to use for sending the event
-            host_config (dict)  : contains configurations for the host.
-        """
-        logger.debug(
-            'Routing event "%s" for router type "%s"',
-            event_name,
-            router_type
-        )
-
-        try:
-            client_class = ROUTER_STRATEGY_MAPPING[router_type]
-        except KeyError:
-            logger.error('Unsupported routing strategy detected: {}'.format(router_type))
-            return
-
-        try:
-            client = client_class(**host_config)
-            client.send(event)
-            logger.debug(
-                'Successfully dispatched event "{}" using client strategy "{}"'.format(
-                    event_name,
-                    router_type
-                )
-            )
-
-        except Exception:   # pylint: disable=broad-except
-            logger.exception(
-                'Exception occured while trying to dispatch event "{}"'.format(
-                    event_name,
-                ),
-                exc_info=True
-            )
