@@ -23,7 +23,7 @@ User = get_user_model()
 UTC_DATETIME_FORMAT = '%Y-%m-%dT%H:%M:%S.%f'
 
 
-def get_anonymous_user_id_by_username(username):
+def get_anonymous_user_id(username_or_id):
     """
     Generate anonymous user id.
 
@@ -31,16 +31,26 @@ def get_anonymous_user_id_by_username(username):
     In case of anonymous user, return random uuid.
 
     Arguments:
-        username (str):     username for the learner
+        username_or_id (str):     username for the learner
 
     Returns:
         str
     """
-    try:
-        user = User.objects.get(username=username)
-    except User.DoesNotExist:
+    user = user_id = username = None
+    if username_or_id:
+        try:
+            user_id = int(username_or_id)
+        except ValueError:
+            username = username_or_id
+
+    if username:
+        user = User.objects.filter(username=username).first()
+    elif user_id:
+        user = User.objects.filter(id=user_id).first()
+
+    if not user:
         logger.info('User with username "%s" does not exist. '
-                    'Cannot generate anonymous ID', username)
+                    'Cannot generate anonymous ID', username_or_id)
 
         anonymous_id = str(uuid4())
     else:
@@ -78,6 +88,8 @@ def convert_seconds_to_iso(seconds):
     Returns:
         str
     """
+    if seconds is None:
+        return None
     return duration_isoformat(timedelta(
         seconds=seconds
     ))
@@ -105,23 +117,23 @@ def convert_datetime_to_iso(current_datetime):
     return formatted_datetime
 
 
-def get_block_id_from_event_referrer(event):
+def get_block_id_from_event_referrer(referrer):
     """
     Derive and return block id from event referrer.
 
     Arguments:
-        event (dict):   event dictionary object.
+        referrer (str):   referrer string.
 
     Returns:
         str or None
     """
-    try:
-        parsed = urlparse(event['context']['referer'])
+    if referrer is not None:
+        parsed = urlparse(referrer)
         block_id = parse_qs(parsed.query)['activate_block_id'][0]
-        return block_id
-    except (KeyError, IndexError):
-        logger.error('Could not get block id for event "%s"', event.get('name'))
-        return None
+    else:
+        block_id = None
+
+    return block_id
 
 
 def make_video_block_id(video_id, course_id, video_block_name='video', block_version='block-v1'):
@@ -155,9 +167,35 @@ def make_course_url(course_id):
     Returns:
         str
     """
+    if course_id is None:
+        return None
     return '{root_url}{course_root_url}'.format(
         root_url=settings.LMS_ROOT_URL,
         course_root_url=reverse('course_root', kwargs={
             'course_id': course_id
         })
     )
+
+
+def backend_cache_ttl():
+    """
+    Return cache time out.
+
+    Returns:
+        int
+    """
+    return getattr(settings, 'EVENT_TRACKING_BACKENDS_CACHE_TTL', 600)
+
+
+def get_business_critical_events():
+    """
+    Return list of business critical events.
+
+    Returns:
+        list
+    """
+    return getattr(settings, 'EVENT_TRACKING_BACKENDS_BUSINESS_CRITICAL_EVENTS', [
+        'edx.course.enrollment.activated',
+        'edx.course.enrollment.deactivated',
+        'edx.course.grade.passed.first_time'
+    ])
