@@ -54,7 +54,7 @@ class ProblemEventsTransformers(CaliperTransformer):
         Returns:
             str
         """
-        return EVENT_TYPE_MAP[self.event['name']]
+        return EVENT_TYPE_MAP[self.get_data('name', True)]
 
     def get_action(self):
         """
@@ -63,7 +63,7 @@ class ProblemEventsTransformers(CaliperTransformer):
         Returns:
             str
         """
-        return EVENT_ACTION_MAP[self.event['name']]
+        return EVENT_ACTION_MAP[self.get_data('name', True)]
 
     def get_object(self):
         """
@@ -72,29 +72,38 @@ class ProblemEventsTransformers(CaliperTransformer):
         Returns:
             dict
         """
-        object_id = self.find_nested('problem_id')
+        self.event_version = "1.0"
+        self.backend_name = 'caliper'
+        object_id = None
+        event_data = None
+        data = self.get_data('data')
+        if data and isinstance(data, dict):
+            event_data = data
+            object_id = event_data.get('problem_id', event_data.get('module_id', None))
+
         if not object_id:
-            object_id = self.find_nested('module_id')
-        if not object_id:
-            object_id = get_block_id_from_event_referrer(self.event) or self.event['context']['referer']
+            object_id = get_block_id_from_event_referrer(self.get_data('context.referer', True))
 
         caliper_object = self.transformed_event['object']
         caliper_object.update({
             'id': object_id,
-            'type': OBJECT_TYPE_MAP[self.event['name']],
+            'type': OBJECT_TYPE_MAP[self.get_data('name', True)],
         })
 
-        if self.event['context'].get('event_source') == 'browser':
-            caliper_object['extensions'].update({
-                'data': self.event['data']
-            })
-        else:
-            caliper_object['extensions'].update(self.event['data'])
-            # problem_id is already being used as object id
-            if 'problem_id' in caliper_object['extensions']:
-                del caliper_object['extensions']['problem_id']
-
-        if 'user_id' in caliper_object['extensions']:
-            del caliper_object['extensions']['user_id']
+        if event_data and isinstance(event_data, dict):
+            extensions = self.extract_subdict_by_keys(
+                event_data, [
+                    'module_id',
+                    'grade',
+                    'max_grade',
+                    'success',
+                    'attempts',
+                    'event_transaction_id',
+                    'event_transaction_type',
+                    'weighted_earned',
+                    'weighted_possible',
+                ]
+            )
+            caliper_object['extensions'].update(extensions)
 
         return caliper_object
