@@ -5,7 +5,7 @@ import json
 
 from django.test import SimpleTestCase
 from django.test.utils import override_settings
-from eventtracking.processors.exceptions import EventEmissionExit
+from eventtracking.processors.exceptions import EventEmissionExit, NoBackendEnabled
 from mock import MagicMock, call, patch, sentinel
 
 from event_routing_backends.processors.caliper.transformer_processor import CaliperProcessor
@@ -29,7 +29,7 @@ class TestCaliperProcessor(SimpleTestCase):
 
     @override_settings(CALIPER_EVENTS_ENABLED=False)
     def test_skip_event_when_disabled(self):
-        with self.assertRaises(EventEmissionExit):
+        with self.assertRaises(NoBackendEnabled):
             self.processor(self.sample_event)
 
     @patch('event_routing_backends.processors.mixins.base_transformer_processor.logger')
