@@ -7,18 +7,13 @@ from tincan import (
     ActivityList,
     Context,
     ContextActivities,
-    Extensions,
     InteractionComponent,
     InteractionComponentList,
     LanguageMap,
     Result,
 )
 
-from event_routing_backends.helpers import (
-    get_anonymous_user_id_by_username,
-    get_block_id_from_event_referrer,
-    make_course_url,
-)
+from event_routing_backends.helpers import get_anonymous_user_id, get_block_id_from_event_referrer, make_course_url
 from event_routing_backends.processors.xapi import constants
 from event_routing_backends.processors.xapi.registry import XApiTransformersRegistry
 from event_routing_backends.processors.xapi.transformer import XApiTransformer, XApiVerbTransformerMixin
@@ -75,6 +70,7 @@ class BaseProblemsTransformer(XApiTransformer, XApiVerbTransformerMixin):
     """
     additional_fields = ('context', )
     verb_map = VERB_MAP
+    event_version = 1.0
 
     def get_object(self):
         """
@@ -83,9 +79,14 @@ class BaseProblemsTransformer(XApiTransformer, XApiVerbTransformerMixin):
         Returns:
             `Activity`
         """
+        object_id = None
+        data = self.get_data('data')
+        if data and isinstance(data, dict):
+            object_id = data.get('problem_id', data.get('module_id', None))
+
         # TODO: Add definition[name] of problem once it is added in the event.
         return Activity(
-            id=self.find_nested('problem_id') or self.find_nested('module_id'),
+            id=object_id,
             definition=ActivityDefinition(
                 type=constants.XAPI_ACTIVITY_INTERACTION,
             ),
@@ -98,12 +99,14 @@ class BaseProblemsTransformer(XApiTransformer, XApiVerbTransformerMixin):
         Returns:
             `Context`
         """
-        return Context(
-            registration=get_anonymous_user_id_by_username(
-                self.event['context']['username']
+
+        context = Context(
+            registration=get_anonymous_user_id(
+                self.extract_username_or_userid()
             ),
             contextActivities=self.get_context_activities()
         )
+        return context
 
     def get_context_activities(self):
         """
@@ -114,7 +117,7 @@ class BaseProblemsTransformer(XApiTransformer, XApiVerbTransformerMixin):
         """
         parent_activities = [
             Activity(
-                id=make_course_url(self.event['context']['course_id']),
+                id=make_course_url(self.get_data('context.course_id')),
                 object_type=constants.XAPI_ACTIVITY_COURSE
             ),
         ]
@@ -146,7 +149,7 @@ class ProblemSubmittedTransformer(BaseProblemsTransformer):
         Returns:
             `Result`
         """
-        event_data = self.event['data']
+        event_data = self.get_data('data')
         return Result(
             success=event_data['weighted_earned'] >= event_data['weighted_possible'],
             score={
@@ -176,11 +179,8 @@ class ProblemCheckTransformer(BaseProblemsTransformer):
 
         # If the event was generated from browser, there is no `problem_id`
         # or `module_id` field. Therefore we get block id from the referrer.
-        if self.event['context']['event_source'] == 'browser':
-            xapi_object.id = get_block_id_from_event_referrer(self.event) or self.find_nested('referer')
-            xapi_object.definition.extensions = Extensions({
-                'data': self.event['data']
-            })
+        if self.get_data('context.event_source') == 'browser':
+            xapi_object.id = get_block_id_from_event_referrer(self.get_data('context.referer', True))
             return xapi_object
 
         interaction_type = self._get_interaction_type()
@@ -203,7 +203,7 @@ class ProblemCheckTransformer(BaseProblemsTransformer):
         Returns:
             str
         """
-        response_type = self.find_nested('response_type')
+        response_type = self.get_data('response_type')
         try:
             return INTERACTION_TYPES_MAP[response_type]
         except KeyError:
@@ -230,7 +230,9 @@ class ProblemCheckTransformer(BaseProblemsTransformer):
         Returns:
             list
         """
-        answers = self.find_nested('answers')
+        answers = self.get_data('data.answers')
+        if answers is None:
+            answers = {}
         try:
             answers = next(iter(answers.values()))
             if isinstance(answers, str):
@@ -254,7 +256,7 @@ class ProblemCheckTransformer(BaseProblemsTransformer):
             InteractionComponentList<InteractionComponent>
         """
         answers = self._get_answers_list()
-        answers_descriptions = self.find_nested('answer')
+        answers_descriptions = self.get_data('answer')
         if isinstance(answers_descriptions, str):
             answers_descriptions = [answers_descriptions, ]
         return InteractionComponentList([
@@ -272,18 +274,20 @@ class ProblemCheckTransformer(BaseProblemsTransformer):
             Result
         """
         # Do not transform result if the event is generated from browser
-        if self.event['context']['event_source'] == 'browser':
+        if self.get_data('context.event_source') == 'browser':
             return None
 
-        event_data = self.event['data']
-
+        event_data = self.get_data('data')
+        if event_data is None:
+            event_data = {}
         return Result(
-            success=event_data['success'] == 'correct',
+            success=event_data.get('success', None) == 'correct',
             score={
                 'min': 0,
-                'max': event_data['max_grade'],
-                'raw': event_data['grade'],
-                'scaled': event_data['grade']/event_data['max_grade']
+                'max': event_data.get('max_grade', None),
+                'raw': event_data.get('grade', None),
+                'scaled': event_data.get('grade', None) / event_data.get('max_grade', None)
+                if event_data.get('max_grade', None) is not None and event_data.get('grade', None) is not None else None
             },
-            response=self.find_nested('answers')
+            response=event_data.get('answers', None)
         )
