@@ -21,7 +21,6 @@ The (soon to be) updated event names are as following:
 - edx.video.position.changed
 - edx.video.completed (proposed)
 """
-from logging import getLogger
 
 from tincan import (
     Activity,
@@ -36,7 +35,7 @@ from tincan import (
 
 from event_routing_backends.helpers import (
     convert_seconds_to_iso,
-    get_anonymous_user_id_by_username,
+    get_anonymous_user_id,
     make_course_url,
     make_video_block_id,
 )
@@ -44,9 +43,6 @@ from event_routing_backends.processors.xapi import constants
 from event_routing_backends.processors.xapi.registry import XApiTransformersRegistry
 from event_routing_backends.processors.xapi.transformer import XApiTransformer, XApiVerbTransformerMixin
 
-logger = getLogger(__name__)
-
-
 VERB_MAP = {
     'load_video': {
         'id': constants.XAPI_VERB_INITIALIZED,
@@ -110,6 +106,7 @@ class BaseVideoTransformer(XApiTransformer, XApiVerbTransformerMixin):
     """
     additional_fields = ('context', )
     verb_map = VERB_MAP
+    event_version = 1.0
 
     def get_object(self):
         """
@@ -118,19 +115,18 @@ class BaseVideoTransformer(XApiTransformer, XApiVerbTransformerMixin):
         Returns:
             `Activity`
         """
-        course_id = self.find_nested('course_id')
-        video_id = self.event['data']['id']
+        course_id = self.get_data('context.course_id', True)
+
+        video_id = self.get_data('data.id', True)
 
         object_id = make_video_block_id(course_id=course_id, video_id=video_id)
+
         return Activity(
             id=object_id,
             definition=ActivityDefinition(
                 type=constants.XAPI_ACTIVITY_VIDEO,
                 # TODO: how to get video's display name?
                 name=LanguageMap({constants.EN: 'Video Display Name'}),
-                extensions=Extensions({
-                    'code': self.event['data']['code']
-                })
             ),
         )
 
@@ -141,12 +137,13 @@ class BaseVideoTransformer(XApiTransformer, XApiVerbTransformerMixin):
         Returns:
             `Context`
         """
-        return Context(
-            registration=get_anonymous_user_id_by_username(
-                self.event['context']['username']
+        context = Context(
+            registration=get_anonymous_user_id(
+                self.extract_username_or_userid()
             ),
             contextActivities=self.get_context_activities()
         )
+        return context
 
     def get_context_activities(self):
         """
@@ -157,7 +154,7 @@ class BaseVideoTransformer(XApiTransformer, XApiVerbTransformerMixin):
         """
         parent_activities = [
             Activity(
-                id=make_course_url(self.event['context']['course_id']),
+                id=make_course_url(self.get_data('context.course_id')),
                 object_type=constants.XAPI_ACTIVITY_COURSE
             ),
         ]
@@ -187,7 +184,7 @@ class VideoLoadedTransformer(BaseVideoTransformer):
 
         # TODO: Add completion threshold once its added in the platform.
         context.extensions = Extensions({
-            constants.XAPI_CONTEXT_VIDEO_LENGTH: convert_seconds_to_iso(self.find_nested('duration')),
+            constants.XAPI_CONTEXT_VIDEO_LENGTH: convert_seconds_to_iso(self.get_data('data.duration')),
         })
         return context
 
@@ -213,7 +210,7 @@ class VideoInteractionTransformers(BaseVideoTransformer):
         """
         return Result(
             extensions=Extensions({
-                constants.XAPI_RESULT_VIDEO_TIME: convert_seconds_to_iso(self.find_nested('currentTime'))
+                constants.XAPI_RESULT_VIDEO_TIME: convert_seconds_to_iso(self.get_data('data.currentTime'))
             })
         )
 
@@ -235,10 +232,10 @@ class VideoCompletedTransformer(BaseVideoTransformer):
         """
         return Result(
             extensions=Extensions({
-                constants.XAPI_RESULT_VIDEO_TIME: convert_seconds_to_iso(self.find_nested('duration'))
+                constants.XAPI_RESULT_VIDEO_TIME: convert_seconds_to_iso(self.get_data('data.duration'))
             }),
             completion=True,
-            duration=convert_seconds_to_iso(self.find_nested('duration'))
+            duration=convert_seconds_to_iso(self.get_data('data.duration'))
         )
 
 
@@ -259,7 +256,7 @@ class VideoPositionChangedTransformer(BaseVideoTransformer):
         """
         return Result(
             extensions=Extensions({
-                constants.XAPI_RESULT_VIDEO_TIME_FROM: convert_seconds_to_iso(self.find_nested('old_time')),
-                constants.XAPI_RESULT_VIDEO_TIME_TO: convert_seconds_to_iso(self.find_nested('new_time')),
+                constants.XAPI_RESULT_VIDEO_TIME_FROM: convert_seconds_to_iso(self.get_data('data.old_time')),
+                constants.XAPI_RESULT_VIDEO_TIME_TO: convert_seconds_to_iso(self.get_data('data.new_time')),
             }),
         )
