@@ -1,9 +1,11 @@
 """
 xAPI Transformer Class
 """
+import uuid
+
 from tincan import Agent, LanguageMap, Statement, Verb
 
-from event_routing_backends.helpers import get_anonymous_user_id_by_username
+from event_routing_backends.helpers import get_anonymous_user_id
 from event_routing_backends.processors.mixins.base_transformer import BaseTransformerMixin
 from event_routing_backends.processors.xapi import constants
 
@@ -29,6 +31,7 @@ class XApiTransformer(BaseTransformerMixin):
             `Statement`
         """
         transformed_props = super().transform()
+        transformed_props["version"] = constants.XAPI_TRANSFORMER_VERSION
         return Statement(**transformed_props)
 
     def base_transform(self):
@@ -38,7 +41,8 @@ class XApiTransformer(BaseTransformerMixin):
         # TODO: Move context registration in base transform
         self.transformed_event = {
             'actor': self.get_actor(),
-            'timestamp': self.get_timestamp()
+            'timestamp': self.get_timestamp(),
+            'id': uuid.uuid4()
         }
 
     def get_actor(self):
@@ -48,7 +52,8 @@ class XApiTransformer(BaseTransformerMixin):
         Returns:
             `Agent`
         """
-        user_uuid = get_anonymous_user_id_by_username(self.event['context'].get('username'))
+
+        user_uuid = get_anonymous_user_id(self.extract_username_or_userid())
         return Agent(
             openid='https://openedx.org/users/user-v1/%s' % user_uuid,
         )
@@ -60,7 +65,7 @@ class XApiTransformer(BaseTransformerMixin):
         Returns:
             str
         """
-        return self.event['timestamp']
+        return self.get_data('timestamp')
 
 
 class XApiVerbTransformerMixin:
@@ -83,7 +88,7 @@ class XApiVerbTransformerMixin:
         Returns:
             `Verb`
         """
-        event_name = self.event['name']
+        event_name = self.get_data('name', True)
 
         verb = self.verb_map[event_name]
 
